/*
 *   Copyright (C) 2021 Arsen Musayelyan
 *
 *   This program is free software: you can redistribute it and/or modify
 *   it under the terms of the GNU General Public License as published by
 *   the Free Software Foundation, either version 3 of the License, or
 *   (at your option) any later version.
 *
 *   This program is distributed in the hope that it will be useful,
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *   GNU General Public License for more details.
 *
 *   You should have received a copy of the GNU General Public License
 *   along with this program.  If not, see <https://www.gnu.org/licenses/>.
 */

package main

import (
	"github.com/traefik/yaegi/interp"
	"os/exec"
	"reflect"
)

// Create custom package for trident
var tridentSymbols = interp.Exports{"trident": {
	"Say": reflect.ValueOf(Say),
}}

// Function to say text using mimic text-to-speech
func Say(text string, args ...string) {
	// If mimic exists in PATH
	if _, err := exec.LookPath("mimic"); err == nil {
		// Set initial argument slice to contain text
		argSlice := []string{"-t", text}
		// Add any additional arguments to slice
		argSlice = append(argSlice, args...)
		// Create and run command
		exec.Command("mimic", argSlice...).Run()
	} else {
		// If mimic does not exist in PATH, warn user
		log.Warn().Err(err).Str("text", text).Msg("Cannot perform text to speech")
	}
}